#
# spec file for package python-Pyro4
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-Pyro4
Version:        4.79
Release:        bp153.1.19
Summary:        Distributed object middleware for Python (RPC)
License:        MIT
URL:            https://github.com/irmen/Pyro4
Source:         https://files.pythonhosted.org/packages/source/P/Pyro4/Pyro4-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-serpent >= 1.27
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     ca-certificates
Recommends:     python-cloudpickle >= 0.4.0
Recommends:     python-dill >= 0.2.6
Recommends:     python-msgpack-python >= 0.5.2
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module cloudpickle >= 0.4.0}
BuildRequires:  %{python_module dill >= 0.2.6}
BuildRequires:  %{python_module msgpack-python >= 0.5.2}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module serpent >= 1.27}
BuildRequires:  ca-certificates
%if %{with python2}
BuildRequires:  python-selectors34
%endif
# /SECTION
%ifpython2
Requires:       python-selectors34
%endif
%python_subpackages

%description
Pyro means PYthon Remote Objects.

It is a library for building applications in which objects can talk
to each other over the network. One can use normal Python method
calls, with almost every possible parameter and return value type,
and Pyro takes care of locating the right object on the right system
to execute the method. It also provides a set of features that enable
building distributed applications. Pyro is a pure Python library and
runs on many different platforms and Python versions.

%prep
%setup -q -n Pyro4-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_clone -a %{buildroot}%{_bindir}/pyro4-check-config
%python_clone -a %{buildroot}%{_bindir}/pyro4-flameserver
%python_clone -a %{buildroot}%{_bindir}/pyro4-httpgateway
%python_clone -a %{buildroot}%{_bindir}/pyro4-ns
%python_clone -a %{buildroot}%{_bindir}/pyro4-nsc
%python_clone -a %{buildroot}%{_bindir}/pyro4-test-echoserver

%check
# testContextAndSock missing cert fixtures https://github.com/irmen/Pyro4/issues/216
# socket tests require at least lo interface thus skip them
skip="testContextAndSock"
skip+=" or testGetIP or testAutoClean"
skip+=" or testBroadcast or testBCstart"
skip+=" or testStartNSfunc or testStartNSfunc"
skip+=" or testResolveWrongHmac"
skip+=" or testResolveAsymmetricHmacUsage"
skip+=" or testResolve"
skip+=" or testPyroname"
skip+=" or testLookupAndRegister"
skip+=" or testBCLookup0000"
skip+=" or testRefuseDottedNames"
skip+=" or testMulti"
skip+=" or testLookupUnixsockParsing"
skip+=" or testLookupInvalidHmac"
skip+=" or testLookupAndRegister"
skip+=" or testDaemonPyroObj"
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib}:./tests/PyroTests py.test-%{$python_bin_suffix} -v -k "not ($skip)"

%post
%{python_install_alternative pyro4-check-config pyro4-flameserver pyro4-httpgateway pyro4-ns pyro4-nsc pyro4-test-echoserver}

%postun
%python_uninstall_alternative pyro4-check-config

%files %{python_files}
%license LICENSE
%python_alternative %{_bindir}/pyro4-check-config
%python_alternative %{_bindir}/pyro4-flameserver
%python_alternative %{_bindir}/pyro4-httpgateway
%python_alternative %{_bindir}/pyro4-ns
%python_alternative %{_bindir}/pyro4-nsc
%python_alternative %{_bindir}/pyro4-test-echoserver
%{python_sitelib}/*

%changelog
* Fri Mar 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.79:
  * cython compatibility fix
  * removed explicit version checks of dependencies such as serpent
* Fri Jan 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Properly conditionalize python2 build for older openSUSE
* Thu Jan  9 2020 Todd R <toddrme2178@gmail.com>
- Update to 4.77
  * dropped support for Python 3.4 (which has reached end-of-life
    status). Supported Python versions are now 2.7, and 3.5 or
    newer.
  * URIs now allow spaces in the location part. Useful for unix
    domain sockets.
- Dropped python2 subpackage due to dropping backports dependency.
* Tue Sep 24 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.76:
  * corrected bogus space in worker thread name
  * thread server can now be cleanly stopped with SIGINT / Ctrl-C on Windows
  * the behavior of the NATPORT config item has been corrected to be in line with the API behavior of the Daemon
  * certs are now included in sdist archive so the ssl unit tests also run as intended
  * now correctly checks for write access to the correct logfile location, instead of assuming the current directory
* Wed Mar  6 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 4.75:
  * include LICENSE file in distribution
  * avoid decode error when dealing with memoryview annotations
  * serpent 1.27 required to avoid regression in previous version
  * fixed marshal serializer problem that prevented it to even call register() in the name server.
  * msgpack, json and marshal serializers now understand how to serialize array.array the same way serpent already did
  * fixed distributed-mandelbrot example to actually run multiple concurrent calculations.
  * missing API method doc added on NameServer.count()
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Ensure neutrality of description.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to Pyro 4.72
  * (source files: normalized line endings to LF)
  * the -k command line option to supply a HMAC encryption key on the command line for the name server, nsc,
    echoserver, flameserver and httpgateway tools is now deprecated (and will print a warning if used).
    It is a security issue because the key used is plainly visible.
    If you require proper security, use Pyro's 2-way SSL feature. Alternatively, set the HMAC key in the (new) environment
    variable PYRO_HMAC_KEY if you still have to use it before launching the aforementioned tools.
- Update to Pyro 4.71
  * updated ``msgpack`` dependency (was ``msgpack-python`` but that name is now deprecated)
  * fixed restart and force reload commands of the contrib/init.d/pyro4-nsd script, and changed its port binding
    from 9999 back to 9090 which is Pyro's default.
  * serpent 1.24 library now required to fix some api deprecation warnings when using Python 3.7 or newer.
  * updated sphinx documentation theme
- Update to Pyro 4.70
  * **incompatible API change** for python 3.7 compatibility: renaming of ``async`` function and keyword arguments in the API:
    Renamed ``Pyro4.core.async`` to ``Pyro4.core.asyncproxy`` (and its occurrence in ``Pyro4``)
    and the ``async`` keyword argument in some methods to ``asynchronous``.
    This had to be done because ``async`` (and ``await``) are now parsed as keywords in Python 3.7 and using them otherwise will result
    in a SyntaxError when loading the module.
    It is suggested you stop using the ``asyncproxy`` function and instead create asynchronous proxies using the ``_pyroAsync``
    method on the regular proxy.
  * For existing code running on Python *older than 3.7*, a backwards compatibility feature is present to still provide the
    ``async`` function and keyword arguments as they were supported on previous Pyro versions.
    But also for that older environments, it's advised to migrate away from them and start using the new names.
  * Proxy and Daemon have a new 'connected_socket' parameter. You can set it to a user-supplied connected socket that must
    be used by them instead of creating a new socket for you. Connected sockets can be created using the socket.socketpair()
    function for instance, and allow for easy and efficient communication over an internal socket between
    parent-child processes or threads, using Pyro.  Also see the new 'socketpair' example.
  * dropped support for Python 3.3 (which has reached end-of-life status). Supported Python versions are now 2.7, and 3.4 or newer.
    (the life cycle status of the Python versions can be seen here https://devguide.python.org/#status-of-python-branches)
- spec file cleanups
* Wed Nov  8 2017 toddrme2178@gmail.com
- Initial version
